@@ -14,6 +14,7 @@ from datetime import datetime
 from collections.abc import MutableMapping
 from urllib.parse import urlparse, urlunparse
 from centrifuge_cli.policy import CentrifugePolicyCheck
+from centrifuge_cli.stats import CentrifugeStats
 from centrifuge_cli import __version__ as PACKAGE_VERSION
 
 
@@ -211,6 +212,44 @@ def list_command(cli):
     return(result)
 
 
+def get_stats_obj(cli, ctx, include_individuals):
+    outfmt = cli.outfmt
+    cli.outfmt = 'json'
+    cli.echo_enabled = False
+    cli.limit = -1
+
+    reports_json = json.loads(ctx.invoke(list_command))
+    users_json = json.loads(ctx.invoke(users_list))
+
+    stats_obj = CentrifugeStats(reports_json, users_json, include_individuals)
+
+    cli.echo_enabled = True
+    cli.outfmt = outfmt
+    return(stats_obj)
+
+
+@reports.command(name='stats-summary')
+@click.option('--include-individuals', help='Will include statistics for accounts without an Organization', is_flag=True)
+@click.pass_context
+@pass_cli
+def stats_summary(cli, ctx, include_individuals):
+    stats_obj = get_stats_obj(cli, ctx, include_individuals)
+    result = stats_obj.get_summary(cli.outfmt)
+    cli.echo(result)
+    return(result)
+
+
+@reports.command(name='stats-detailed')
+@click.option('--include-individuals', help='Will include statistics for accounts without an Organization', is_flag=True)
+@click.pass_context
+@pass_cli
+def stats_detailed(cli, ctx, include_individuals):
+    stats_obj = get_stats_obj(cli, ctx, include_individuals)
+    result = stats_obj.get_detailed(cli.outfmt, cli.endpoint_scheme, cli.endpoint_netloc)
+    cli.echo(result)
+    return(result)
+
+
 @reports.command()
 @click.argument('searchterm', required=True)
 @pass_cli
@@ -440,7 +479,7 @@ def users(cli):
 
 @users.command(name="list")
 @pass_cli
-def user_list(cli):
+def users_list(cli):
     result = cli.do_GET('/api/user')
     cli.echo(result)
     return(result)
